//  GFAX - Gnome fax application
//  Copyright (C) 2003 George A. Farris
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

namespace gfax {
	using System;
	using System.Collections;
	
	public class Fax
	{
		static Hylafax hfax;
		static Mgetty mfax;
				
		public static string get_server_status ()
		{
			string status;
			
			if (Settings.TransmitAgent == "hylafax") {
				hfax = new Hylafax();
				
				if ( !hfax.connect() )
					return ("No Connection");
				status = hfax.status("status");
				hfax.close();
				return (status);
			} else {
				return ("Using Mgetty");
			}
		}

		public static ArrayList get_queue_status (string queue)
		{
			ArrayList list = new ArrayList();
			
			if (Settings.TransmitAgent == "hylafax") {
				
				string reply;
				
				hfax = new Hylafax();
				if ( !hfax.connect() ) {
					HylafaxQueue hq = new HylafaxQueue();
					hq.Jobid = "";
					hq.Number = "";
					hq.Status = "";
					hq.Owner = "";
					hq.Pages = "";
					hq.Dials = "";
					hq.Error = "";
					hq.Sendat = "";
					
					list.Add(hq);
					
				}else {
					reply = hfax.status(queue);
					if (reply.Length < 1) {		// no status
						HylafaxQueue hq = new HylafaxQueue();
						hq.Jobid = "";
						hq.Number = "";
						hq.Status = "";
						hq.Owner = "";
						hq.Pages = "";
						hq.Dials = "";
						hq.Error = "";
						hq.Sendat = "";
					
						list.Add(hq);
					} else {
						foreach (string s in reply.Split('\n')) {
							if (s.Length == 0 )
								break;
    	     				string[] sa = s.Split('=');
							HylafaxQueue hq = new HylafaxQueue();
							if ( sa[0].Length != 0 )
								hq.Jobid = sa[0];
							else
								hq.Jobid = "";
							if ( sa[1].Length != 0 )
								hq.Number = sa[1];
							else
								hq.Number = "";	
							if ( sa[2].Length != 0 )
								hq.Status = sa[2];
							else
								hq.Status = "";
							if ( sa[3].Length != 0 )
								hq.Owner = sa[3];
							else
								hq.Owner = "";	
							if ( sa[4].Length != 0 )
								hq.Pages = sa[4];
							else
								hq.Pages = "";
							if ( sa[5].Length != 0 )
								hq.Dials = sa[5];
							else
								hq.Dials = "";	
							if ( sa[6].Length != 0 )
								hq.Error = sa[6];
							else
							hq.Error = "";
							if ( sa[7].Length != 0 ) { //2004/03/09 18.01.51
								string[] sa1 = sa[7].Split(' ');  //sa1[1] = 18.01.51
								string[] sa2 = sa1[1].Split('.'); //sa2[0] = 18
								string[] sa3 = sa1[0].Split('/'); //sa3[0] = 2004
								
								DateTime temp = new DateTime(
										Convert.ToInt32(sa3[0]), //Year
										Convert.ToInt32(sa3[1]), //Month
										Convert.ToInt32(sa3[2])  //Day
										);
								string dow = temp.DayOfWeek.ToString();
								hq.Sendat = "[" + dow.Substring(0,3) + "] " + sa2[0] + ":" + sa2[1];  //sa[7];
							} else
								hq.Sendat = "";
							
							list.Add(hq);
						}
					}
				}
				hfax.close();
				
			} else {
				list.Add("Using Mgetty");
			}
			return (list);		
		}

		public static void sendfax (string fname)
		{
			string remote_fname;
				
			if (Settings.TransmitAgent == "hylafax") {
				hfax = new Hylafax();
				// hylafax actually stores the file to the server
				hfax.connect();
				remote_fname = hfax.send_init(fname);
				
				// if "Cancel" button pressed on progess bar
				if (remote_fname == "cancelled") 
					return;
				
				#if DEBUGHYLAFAX
					Console.WriteLine("[Fax.sendfax] Remote file name is : {0}", remote_fname);
				#endif
				
				IEnumerator enu = gfax.Destinations.GetEnumerator();
    	  		while ( enu.MoveNext() ) {
    	     		// TODO try catch exception here
					
					hfax.send(remote_fname, (Contact)enu.Current);
				
					// open the log and log out going fax to server
					// Date Time PhoneNumber Organization ContactPerson
					// log file is in ~/.etc/gfax
					if (Settings.LogEnabled)
						log_it((Contact)enu.Current);
				}
			}	
		}
		
		public static void log_it (Contact contact)
		{
		
		}
		
		public static void delete_job (string jobid)
		{
			if (Settings.TransmitAgent == "hylafax") {
				hfax = new Hylafax();
				hfax.connect();
				hfax.job_select(jobid);
				hfax.job_kill();
				hfax.job_delete();
			}
		}
	}
	
}
